#' @importFrom ggplot2 autoplot
#' @export
ggplot2::autoplot

#' @importFrom magrittr %>%
#' @export
magrittr::`%>%`

#' @importFrom generics fit
#' @export
generics::fit

#' @importFrom generics fit_xy
#' @export
generics::fit_xy

#' @importFrom generics tidy
#' @export
generics::tidy

#' @importFrom generics glance
#' @export
generics::glance

#' @importFrom generics augment
#' @export
generics::augment

#' @importFrom generics required_pkgs
#' @export
generics::required_pkgs

#' @importFrom hardhat extract_spec_parsnip
#' @export
hardhat::extract_spec_parsnip

#' @importFrom hardhat extract_fit_engine
#' @export
hardhat::extract_fit_engine

#' @importFrom hardhat extract_parameter_set_dials
#' @export
hardhat::extract_parameter_set_dials

#' @importFrom hardhat extract_parameter_dials
#' @export
hardhat::extract_parameter_dials

#' @importFrom hardhat tune
#' @export
hardhat::tune
